---
title: Some Post
date: 1970-01-01
tags:
  - markdown
  - test
  - tag with spaces
---
This is a post wherein markdown is demonstrated. Watch how I
choose to *emphasize* some text and **strengthen** other text.

## Behold, A Heading!

Wow, what a post this is. It even has bullet points:

* First one
* and then another
* like a whole trio or something

> I will also demonstrate some block quotes
> such as this one.

> Another block quote follows the first.
